DateTimePickerComponent class

Inheritance

Constructors

DateTimePickerComponent({required DateTimePickerComponentData componentData, required DynamicFormSettings formFieldSettings, required List<ComponentLinker>? parentComponents})

Properties

componentData → DateTimePickerComponentData
finalinherited
componentId → String
no setterinherited
componentWidgetData → ComponentWidgetData<DateTime, DateTimePickerComponentData>
no setterinherited
data → dynamic
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasValidData → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDependent(ComponentLinker dependent) → void
inherited
addError(Object? error) → void
inherited
clearData({bool goToDefaults = true}) → void
inherited
clearError() → void
inherited
fetchData() → DateTime?
inherited
linkWithParents(Map<String, BaseFormComponent<dynamic, BaseComponentData>> components) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
primitiveData(DateTime? data) → String?
override
toJson() → JsonMap
inherited
toString() → String
A string representation of this object.
inherited
toWidget({required Map<String, BaseFormComponent<dynamic, BaseComponentData>> components}) → Widget
inherited
updateReadOnlyStatus() → void
inherited
updateSettings(DynamicFormSettings settings) → void
inherited
validateAndFetchData({bool reflectErrorsInUI = true}) → DateTime?
inherited
validateData({bool reflectErrorsInUI = true}) → bool
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited