AbstractUnknownFieldParser class abstract

Inheritance

Properties

defaultValue → DataParser<Object?>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator → DataParser<ComponentValidator<Object>>
no setteroverride

Methods

componentData(JsonMap data) → UnknownComponentData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited