OptionsFieldParser<R, C extends BaseOptionsComponentData> class abstract

Inheritance
Implementers

Constructors

OptionsFieldParser()

Properties

defaultValue → DataParser<R?>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
options → DataParser<List<R>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator → DataParser<ComponentValidator<R>>
no setterinherited

Methods

componentData(JsonMap data) → C
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited